API de unidades
Comenzar a utilizar
Como se describe en la sección Compartición de Datos , DCP se trata completamente de datos, y los datos enviados a su DMS por BRP son tan vitales como los datos del concesionario enviados a BRP. Una pieza esencial de datos es el catálogo de unidades de BRP.
La API de Unidades permite a los concesionarios obtener el catálogo de unidades más reciente de BRP en su DMS. Dado que el catálogo de unidades se utiliza en muchas actividades del concesionario, tener el catálogo más reciente en su DMS beneficia a los concesionarios de numerosas maneras, por ejemplo:
- La capacidad de referenciar números de modelo de unidades coherentes en conversaciones con BRP.
- Pedidos de unidades más precisos.
- Mayor conocimiento sobre los cambios más recientes en las unidades.
En resumen, la API de Unidades es un componente central de su integración con BRP.
La API de Unidades ofrece tres tipos de solicitudes:
- Obtener el catálogo completo de unidades.
- Obtener el catálogo de unidades por línea de producto y/o una región específica.
- Obtener los cambios realizados al catálogo de unidades después de una fecha especificada.
- Obtener información sobre un modelo en particular.
¿Por dónde empezar? ¡Léeme primero!
Antes de comenzar a trabajar en esta API, debes leer las siguientes secciones si aún no las has revisado:
- Información Técnica para información técnica general sobre la API y los entornos.
- Autenticación y Credenciales para obtener detalles sobre autenticación y credenciales.
- Proceso de Certificación para obtener detalles sobre el proceso de certificación y Jira.
- Obteniendo Apoyo para obtener detalles sobre cómo recibir ayuda y Jira.
Cuándo llamar a la API
Para las operaciones del concesionario, usar un catálogo de unidades actualizado es esencial.
¡Debe llamar a la API de Unidades al menos una vez al mes para obtener los últimos cambios!
Como se describe en la sección Requisitos Funcionales, debe llamar a la API de Unidades mensualmente para obtener los cambios de los últimos 30 días.
Sin embargo, este es el requisito mínimo. Como se muestra en la sección Obtener los cambios de la última semana puede llamar a la API de Unidades diariamente para obtener los cambios de la última semana.
De esta manera, puede asegurarse de que el concesionario tenga un catálogo de piezas actualizado incluso si la actualización no funciona un día.
Los datos de la API de Unidades se actualizan diariamente y finalizan a las 4:00 hora del Este (ET), por lo que el mejor momento para llamar a la API de Unidades y actualizar su DMS es después de las 4:00 ET.
Cómo llamar a la API
La sección Referencia de la API indica que la API de Unidades ofrece dos servicios: uno para obtener el catálogo completo de unidades o los últimos cambios, y otro para obtener una unidad específica.
Cuando el distribuidor busca un número de modelo específico, el servicio para obtener una unidad específica se llama según sea necesario. En otras palabras, el servicio se llama manualmente.
Como se describe en la sección Requisitos Funcionales el servicio para recuperar el catálogo completo de unidades o los últimos cambios debe ser automatizado.
El distribuidor no tiene que intervenir para actualizar el catálogo de unidades diariamente.
Información técnica
Características
Tipo de API | Tipo de DSP | Versión de DCP | Complejidad |
|---|---|---|---|
Obtener datos de BRP | DMS | V3 - Internacional | Bajo |
Enviar datos a BRP | CRM | V4 - Norteamérica | Un poco más |
Transacción con BRP | | | Algo más |
Autenticación
La API está usando Autenticación de Aplicaciones.
Necesitas un token de acceso válido antes de llamar a esta API o tienes que llamarlos API de Autenticación de Aplicaciones para obtener uno.
¡El token de acceso es válido por 30 minutos! (1799 segundos)
URL base
Prueba | https://qa-cloud-api.brp.com/dcp/v4 |
|---|---|
Producción | https://cloud-api.brp.com/dcp/v4 |
Recurso: Unidad
Cuando se llama para solicitar el catálogo completo de unidades o los últimos cambios, la API de Unidades devuelve una matriz de Unidad recursos. Cada Unidad recurso, mostrado a continuación, contiene toda la información sobre una unidad.
Cuando se llama para obtener una unidad específica, la API de Unidades devuelve una sola Unidad recurso.
Representación JSON
{
"model_no": "00010PA00",
"model_name": "PWC RXT X 300 AUD YL IBR IDF 23",
"product_line": "PWC",
"brand": "seadoo",
"segment": "Performance",
"sales_status_code": "U8",
"last_change_date": "2024-11-27T20:19:03Z",
"product_last_change_date": "2024-11-27T20:19:03Z",
"model_year": "2023",
"characteristics": {
"color": "Millenium Yellow",
"color_icon": "https://brp.com/content/dam/global/en/sea-doo/my23/unit-color-swatches/Millenium-Yellow.png",
"engine": "1630 ACE™- 300",
"engine_power_cc": "1630 cc",
"cylinders": "3",
"engine_power_hp": "300 hp",
"engine_code": "300",
"seats": "3",
"warranty_extended": "BRP limited warranty covers the watercraft for one year.",
"fuel_capacity": "18.5 US gal / 70 L",
"length": "135.9\" / 345.1 cm",
"width": "49.4\" / 125.5 cm",
"height": "45.2\"/ 114.7 cm",
"weight": "829 lb / 376 kg",
"package_label": "RXT-X 300",
"model_description": "RXT-X 300 Tech Package, iDF, iBR, 10PA, Millenium Yellow, 2023"
},
"image_information": [
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my23/studio/performance/side/SEA-MY23-RXT-X-SS-300-Eclipse-Black-00010PC00-Studio-RSide-NA.png",
"image_type": "defaultModelImage"
},
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my23/studio/performance/side/SEA-MY23-RXT-X-SS-300-Eclipse-Black-00010PC00-Studio-RSide-NA.png",
"image_type": "defaultPackageImage"
},
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my23/studio/performance/SEA-MY23-RXT-X-SS-300-Millenium-Yellow-00010PA00-Studio-34FR-NA.png",
"image_type": "packageImage"
}
],
"pricings": [
{
"price_type": "freight",
"currency": "USD",
"region": "US",
"price_valid_from": "2022-11-11T00:00:00Z",
"price_valid_to": "9999-12-31T00:00:00Z",
"price": 550,
"price_last_change_date": "2023-06-15T13:50:20.000Z"
},
{
"price_type": "surcharge",
"currency": "USD",
"region": "US",
"price_valid_from": "2022-11-11T00:00:00Z",
"price_valid_to": "9999-12-31T00:00:00Z",
"price": 615,
"price_last_change_date": "2023-06-15T19:04:07.000Z"
},
{
"price_type": "retail",
"currency": "USD",
"region": "US",
"price_valid_from": "2022-08-07T00:00:00Z",
"price_valid_to": "9999-12-31T00:00:00Z",
"price": 18499,
"price_last_change_date": "2024-11-27T20:19:03Z"
},
{
"price_type": "dealer",
"currency": "USD",
"region": "US",
"price_valid_from": "2022-08-07T00:00:00Z",
"price_valid_to": "9999-12-31T00:00:00Z",
"price": 16279,
"price_last_change_date": "2024-11-27T20:19:03Z"
}
],
"documents": {
"model_description": [
"The RXT-X pairs a high octane attitude with exceptional confidence and convenience, making it the ultimate offshore performance watercraft."
],
"spec_sheet": [
"https://brp.com/content/dam/global/en/sea-doo/my23/documents/specs-sheets/en/SEA-MY23-PERF-RXT-X-SPEC-DPS-ENNA_LR.pdf"
],
"package_description": [
"The ultimate in offshore performance watercraft. The RXT-X brings 300 HP of adrenaline-filled fun to every adventure. The revolutionary hull design and Ergolock seating system offer maximum control and confidence in any conditions."
],
"highlights": [
"Tech Package: BRP Audio Premium system & full color display",
"The most powerful engine in the Sea-Doo lineup",
"Industry leading stability and control",
"Up to 3 passengers"
],
"comparison_sheet": ""
}
}Propiedades
Property | Type | Definition | Notes |
|---|---|---|---|
model_no | string | Code that uniquely identifies a unit model. | Length:9 |
model_name | string | Model name/description. | Max Length:50 |
product_line | string | Code that uniquely identifies the product line. Refer to the Product Lines table below. | Length: 3 |
brand | string | The brand of the model. One of:
| |
segment | string | The segment of a specific unit. Example:
| Max Length:15
|
sales_status_code | string | string Code that identifies the sellable status of the unit. Refer to the Sales Status Code table below. | |
last_change_date | string | Last date and time when this resource has changed | Format: YYYY-MM-DDTHH:MM:SSZ |
product_last_change_date | string | The last date the product was updated. | Format: YYYY-MM-DDTHH:MM:SSZ |
model_year | string | Model year of the unit. |
|
characteristics | Object | The unit characteristics | |
characteristics.color | string | Color description of the unit. | |
characteristics.color_icon | string | A URL displaying an icon showing the shade of color for the unit. | |
characteristics.engine | string | Engine characteristics. | |
characteristics. engine_power_cc | string | The volume displaced by each piston moves from the bottom dead center to the top dead center. This is for all pistons in total. This value is expressed in cubic centimeters. | Max Length: 25 |
characteristics.cylinders | string | Number of cylinders in the engine. | Max Length: 3 |
characteristics. engine_power_hp | string | Engine power in horsepower. | Max Length: 25 |
characteristics.engine_code | string | The code for the model engine. | Max Length: 25 |
characteristics.seats | string | The number of seats in the unit. | Max Length: 3 |
characteristics. warranty_extended | string | The extended warranty coverage for the unit. | Max Length: 50 |
characteristics.fuel_capacity | string | The fuel capacity for the unit is represented in Liters and Gallons. | Max Length: 25 |
characteristics.length | string | The length of the unit is in centimeters and inches. | Max Length: 25 |
characteristics.width | string | The width of the unit is in centimeters and inches. | Max Length: 25 |
characteristics.height | string | The height of the unit is in centimeters and inches. | Max Length: 25 |
characteristics.weight | string | The weight of the unit is in kilograms and pounds. | Max Length: 25 |
characteristics.package_label | string | The package label. | |
characteristics.model_description | string | The complete model description, including the SKU, color, and model year. | |
image_information | List of objects | Image information for the unit. |
|
image_information.image_url | string | Link to the image of the unit. |
|
image_information. image_type | string | The type of image:
|
|
pricings | List of objects | List of the different prices |
|
pricings.region | string | The region where the price is valid. See the table Regions and Currencies below. | Max Length: 5 |
pricings.price_type | string | Code that identifies a type of price. One of:
| * For a Switch product, the dealer and retail prices include the trailer's dealer and retail prices. |
pricings.price_valid_from | string | The date at which the price becomes active. | Format: YYYY-MM-DDTHH:MM:SSZ |
pricings.price_valid_to | string | The date up to which the price remains active. | Format: YYYY-MM-DDTHH:MM:SSZ |
pricings.price | number | Price, excluding taxes, for one unit. | |
pricings.currency | string | Currency in which the price is provided. See the table Regions and Currencies below. | |
price_last_change_date | string | Last date and time at which this resource has changed. | Format: YYYY-MM-DDTHH:MM:SSZ |
documents | List of objects | Unit description and links to related documents. | |
documents. model_description | string | The description of a model in a short sentence. | |
documents.spec_sheet | string | Link to the full specification sheet in PDF format. | |
documents. package_description | string | The description of the unit on the package. | |
documents.highlights | string | Description of the major highlights included in the unit. | |
documents. comparison_sheet | string | The link to the comparison sheet highlights the differences between the BRP and the major competitor units. | |
trailer | object | ❗ Only for the Switch products. Description of the trailer sold with the Switch. | |
product_code | string | | |
product_descr | string | | |
pricings | List of objects | List of the different prices | |
pricings.region | string | The region where the price is valid. See the table Regions and Currencies below. | Max Length: 5 |
pricings.price_type | string | Code that identifies a type of price. One of:
| |
pricings.price_valid_from | string | The date at which the price becomes active. | Format: YYYY-MM-DDTHH:MM:SSZ |
pricings.price_valid_to | string | The date up to which the price remains active. | Format: YYYY-MM-DDTHH:MM:SSZ |
pricings.price | number | Price, excluding taxes, for one trailer. | |
pricings.currency | string | Currency in which the price is provided. See the table Regions and Currencies below. | |
price_last_change_date | string | Last date and time at which this resource has changed. | Format: YYYY-MM-DDTHH:MM:SSZ |
Código de estado de ventas
Clave | Valor | Descripción |
|---|---|---|
U1 | Formulario | La unidad es vendible y se puede pedir mediante el Formulario de Pedido en OMS. |
U2 | Añadir/Cambiar | La unidad es vendible y se puede pedir mediante el Formulario de Pedido, un pedido adicional o un pedido de cambio en OMS. |
U3 | Completo | La unidad es vendible y se puede pedir mediante un pedido adicional o un pedido de cambio en OMS. |
U4 | Formulario/Añadir | La unidad es vendible y se puede pedir mediante el Formulario de Pedido y un pedido adicional en OMS. |
U5 | Formulario/Cambiar | La unidad es vendible y se puede pedir mediante el Formulario de Pedido y un pedido de cambio en OMS. |
U6 | Añadir | La unidad es vendible y se puede pedir mediante un pedido adicional en OMS. |
U7 | Pedido de Cambio | La unidad es vendible y se puede pedir mediante un pedido de cambio en OMS. |
U8 | Mostrar | La unidad no se puede pedir desde BRP pero se muestra en OMS. |
UI | Inactivo | La unidad no se puede pedir desde BRP y no se muestra en OMS. |
Recurso: Lista de unidades
Cuando se llama para solicitar el catálogo completo de unidades o los últimos cambios, la API de Unidades devuelve una matriz de Unidad recursos.
Las respuestas de devoluciones contienen dos objetos que te ayudan a navegar por las páginas del catálogo de unidades.
Representación JSON
{
"items": [
{
List of Units resources
}
],
"links": {
"previous": null,
"next": "https://cloud-api.brp.com/dcp/v4/units?language=en-US&page=2&limit=200"
},
"meta": {
"total_records": 9999,
"total_pages": 87,
"current_page": 2,
"limit": 200
}
}Propiedades
Propiedad | Tipo | Definición |
|---|---|---|
items | Lista de objetos | Lista de recursos Unit que se devuelven. |
links | objeto | Enlaces de paginación. |
links.previous | cadena | URL que se utilizará para recuperar la página anterior. NULL si no existe una página anterior. |
links.next | cadena | URL que se utilizará para recuperar la página siguiente. NULL si no existe una página siguiente. |
meta | objeto | Estadísticas de la solicitud. |
meta.total_records | número | El número de registros devueltos por la solicitud. |
meta.total_pages | número | El número de páginas usando el límite para calcular. |
meta.current_page | número | El número de la página actual o el número de página solicitado. |
meta.limit | número | Límite de los parámetros de la solicitud. |
Enlaces
El Enlaces se puede utilizar para navegar por las páginas devueltas por la API de Unidades.
Cuando un enlace no es NULL, se puede usar para ir a la página anterior o siguiente. Esto simplifica la navegación entre páginas porque no tienes que guardar tu consulta de parámetros; la URL del enlace contiene los parámetros de consulta que proporcionaste y los parámetros de consulta predeterminados para aquellos que no proporcionaste.
Metadatos
El objeto Meta proporciona estadísticas sobre el número de recursos Unit devueltos por tu solicitud y el número de páginas que se pueden esperar.
Esta información puede ser útil para diagnósticos y para verificar que se recibieron todos los recursos Unit.
Limitaciones y restricciones
Formato numérico
Todos los campos numéricos con decimales usan el punto(.) como separador decimal. La coma (,) NO es compatible como separador decimal.
Años de Modelo Disponibles
El catálogo de unidades contiene información del año de modelo 2023 en adelante. No encontrarás información sobre un modelo 2017.
Además, el catálogo de unidades incluye solo los últimos 10 años de modelo.
👉 Un año de modelo BRP está un año en el futuro (como el año de modelo para los fabricantes de automóviles). Esto significa que el año de modelo 2026 estará disponible en 2025.
Cuando tu DMS llame la API de Unidades en 2034, cuando el año de modelo sea 2036, recibirá información sobre los años de modelo 2025 a 2035.
Entendiendo las Unidades
Código de Estado de Venta
Como el concesionario no puede ordenar unidades a través de una API DCP, los códigos de estado de venta de las unidades, enumerados en la tabla Código de Estado de Venta anterior, se proporcionan solo con fines informativos.
Sin embargo, las unidades con el código de estado de venta UI no son vendibles y no se muestran en el OMS, así que es mejor no mostrar estas unidades en tu DMS.
Imágenes del Producto
Generalmente verás enlaces a 3 imágenes para cada unidad devuelta en la respuesta, como se muestra a continuación.
"image_information": [
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-NoSS-M170-Purple-Potion-00030SG00-Studio-RSIDE-CU.png",
"image_type": "defaultModelImage"
},
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-NoSS-M170-Purple-Potion-00030SG00-Studio-RSIDE-CU.png",
"image_type": "defaultPackageImage"
},
{
"image_url": "https://brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-Integrated100W-M170-Teal-Blue-Metallic-00030SD00-Studio-34FR-CU.png",
"image_type": "packageImage"
}
],La imagen del paquete ("image_type": "packageImage") es la más cercana al aspecto de la unidad y debe mostrarse primero.
Si la imagen del paquete no está disponible, la defaultPackageImage debe mostrarse. Y, como puedes imaginar, si la defaultPackageImage no está disponible, la defaultModelImage debe mostrarse.
Veamos un ejemplo usando un producto Sea-Doo, el GTI SE 170. Este modelo tiene 3 códigos de producto.
Código de Producto | Descripción | Color |
|---|---|---|
00030SG00 | GTI SE 170 | Púrpura Medianoche |
00030SA00 | GTI SE 170 | Azul Verdoso / Verde Manta |
00030SD00 | GTI SE 170 (Sistema de Sonido) | Azul Verdoso / Verde Manta |
Los primeros 2 códigos de producto son el mismo modelo en diferentes colores. El tercer producto incluye un sistema de sonido adicional.
Si obtienes la defaultPackageImage o la defaultModelImage para el código de producto 00030SD00 usando el enlace https://brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-NoSS-M170-Purple-Potion-00030SG00-Studio-RSIDE-CU.png, obtienes esto.

Si obtienes la packageImage para el mismo código de producto usando el enlace https://www.brp.com/content/dam/global/en/sea-doo/my25/studio/recreation/gti-se/SEA-MY25-GTI-SE-Integrated100W-M170-Teal-Blue-Metallic-00030SD00-Studio-34FR-CU.png, obtienes esto.

La packageImage es mucho más interesante ya que muestra la unidad en el color correcto y con los altavoces añadidos.
Puedes ver la diferencia al mirar la packageImage para el código de producto 00030SA00, que es del mismo color pero no tiene los altavoces.

Por qué la región US-AK?
La región US-AK es la misma que la región US con una excepción: el valor del precio del flete.
👉 Es importante mostrar el precio de flete correcto para los concesionarios ubicados en Alaska.
Los productos Switch y sus remolques
Los pontones Switch forman parte de la línea de productos Sea-Doo. Tienen la particularidad de que siempre se venden con un remolque.
Por ejemplo, el Switch Cruise Limited 21 - 230 hp en el sitio de BRP incluye un remolque.

Para los productos Switch, la respuesta de la API de Unidades incluye información sobre el remolque, incluyendo los precios del remolque.
t👉 Para los productos Switch, cuando un remolque está disponible, los precios de concesionario y minorista del remolque se agregan a los precios de concesionario y minorista de Switch.
Referencia de la API
curl --location 'https://cloud-api.brp.com/dcp/v4/units?last_change_date=2024-06-01&product_line=SNO®ion=US&limit=3' \
--header 'Authorization: Bearer REPLACE_ME' curl --location 'https://cloud-api.brp.com/dcp/v4/unit/0001BRA00?region=US' \
--header 'Authorization: Bearer REPLACE_ME' Tablas de referencia
Idiomas
Idioma en código de idioma ISO (ISO-639-1 + ISO 3166-1)
Formato: xx-XX
xx: código de idioma en minúsculas
XX: código de país en mayúsculas
Valores de código de idioma compatibles
Código | Idioma |
|---|---|
de | Alemán |
en | Inglés |
es | Español |
fi | Finlandés |
fr | Francés |
it | Italiano |
nl | Neerlandés |
no | Noruego |
pt | Portugués (Brasil) |
sv | Sueco |
Líneas de productos
Clave | Valor |
|---|---|
2WV | Vehículos de dos ruedas |
3WV | Vehículos de tres ruedas |
ATV | Vehículos todoterreno |
PTN | Barcos pontón |
PWC | Motos acuáticas |
SNO | Motonieves |
SSV | Vehículos Side-by-Side |
Regiones y Monedas
Código | País | Región | Moneda | Descripción |
|---|---|---|---|---|
CA | Canadá | | CAD | Todo Canadá, incluidas todas las provincias. |
US | Estados Unidos | | USD | Todos los Estados Unidos. |
US-AK | Estados Unidos | Alaska | USD | Solo el estado de Alaska en los EE. UU. |
Cómo hacerlo
Esta sección proporciona información sobre cómo obtener resultados específicos con la API de Units.
Obtener la primera página
Obtenga la primera página del catálogo completo de unidades. En este escenario, la solicitud se realiza para los distribuidores de EE. UU.
La carga útil de la respuesta contiene la lista de recursos Unit, elenlacesobjeto, y el metaobjeto. La propiedad links.previouses NULL ya que esta es la primera página. La propiedad links.nextcontiene la URL a la siguiente página.
curl --location 'https://cloud-api.brp.com/dcp/v4/units?region=US&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Obtener la siguiente página
Obtén la siguiente página del catálogo completo usando la links.next URL que se encuentra en la carga de la respuesta.
La carga de la respuesta contiene la lista de recursos Unit, el objeto links y el objeto meta. La propiedad links.previous contiene la URL de la primera página. La propiedad links.next contiene la URL de la siguiente página.
curl --location 'https://cloud-api.brp.com/dcp/v4/units?region=US&language=ca-EN&page=2&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Obtener la última página
Obtenga la página siguiente del catálogo completo usando la links.next URL que se encuentra en la carga de la respuesta.
La carga de la respuesta contiene la lista de recursos Unit, el objeto links y el objeto meta. La propiedad links.previous contiene la URL de la página anterior. La propiedad links.next es NULL ya que esta es la última página.
curl --location 'https://cloud-api.brp.com/dcp/v4/units?region=US&language=en-US&limit=2&page=1214' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Obtener los cambios de la semana pasada
Obtén la primera página de los cambios realizados en el catálogo de unidades para la región canadiense.
curl --location 'https://cloud-api.brp.com/dcp/v4/units?region=CA&last_change_date=2024-12-01&page=1&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtener productos para un año de modelo
Obtener una línea de productos específica y un año de modelo para la región de EE. UU.
curl --location 'https://qa-cloud-api.brp.com/dcp/v4/units?region=US&product_line=PWC&language=us-EN&model_year=2024&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtener productos para una marca
Obtener una marca y año de modelo específicos para Canadá.
curl --location 'https://qa-cloud-api.brp.com/dcp/v4/units?region=CA&language=us-EN&brand=seadoo&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtener productos para una marca y año del modelo
Obtener una marca y un año de modelo específicos para Canadá.
curl --location 'https://qa-cloud-api.brp.com/dcp/v4/units?region=CA&language=us-EN&brand=seadoo&model_year=2025&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtener productos para una marca y una línea de productos
Obtener una marca y una línea de productos específicas para Canadá.
❗ Si la marca solicitada no contiene la línea de producto solicitada, no se devuelve nada ❗
Si pides la marca seadoo y la línea de producto SNO, no se devuelve nada.
curl --location 'https://qa-cloud-api.brp.com/dcp/v4/units?region=CA&language=us-EN&brand=canam-offroad&product_line=ATV&limit=2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtener una unidad
Obtenga una unidad específica para la región de Alaska de EE. UU.
La respuesta muestra el flete precio para la región US-AK. Esto se debe a que los costos de flete en Alaska son diferentes a los de otras regiones de EE. UU.
curl --location 'https://cloud-api.brp.com/dcp/v4/unit/000B2PA00?region=US-AK' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Obtener una unidad a partir de un VIN
Probablemente nos dimos cuenta de que la API de Unidades funciona con números de modelo (códigos de producto). El concesionario generalmente no tiene un número de modelo sino un número de serie (VIN).
¿Cómo se obtiene información de la unidad a partir del VIN?
Llame a la API de especificaciones de la unidad para obtener el número de modelo correspondiente al VIN.
De la respuesta de la API de Especificaciones de la Unidad, extraiga el model_number y úselo para llamar a la API de Unidades.
Obtén las Especificaciones de la Unidad
curl --location 'https://cloud-api.brp.com/dcp/v4/unit/3JB3GA449RJ000623/specifications?language=en-US' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtener la unidad
curl --location 'https://cloud-api.brp.com/dcp/v4/unit/0001BRA00?region=US' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Obtener una unidad Switch
Obtener una unidad Switch específica para la región de EE. UU.
curl --location 'https://cloud-api.brp.com/dcp/v4/unit/00041PJ00?region=US' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Manejo de errores
Esta sección presenta varios escenarios de llamadas incorrectas o inapropiadas, que resultan en mensajes de error y resultados inadecuados.
400 Solicitud incorrecta
El código de estado 400 se observa generalmente durante el desarrollo y la integración y no debería recibirse durante las operaciones normales. La respuesta devuelta contiene la información necesaria para corregir el problema.
Muchos problemas pueden causar un código de estado 400; los más comunes se encuentran en la tabla a continuación.
Respuesta | Resolución |
|---|---|
Devuelto si la región no es válida. {
"status": "400",
"id": "rrt-0f82577f1ea003b72-c-ea-3940242-6823134-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "request validation failed",
"payload": {
"details": [
{
"message": "Instance value (\"eg\") not found in enum (possible values: [\"CA\",\"US\",\"US-AK\"]): []"
}
]
}
}
} | Asegúrese de llamar a la API con una región válida. |
Formato de fecha de último cambio no válido. {
"status": "400",
"id": "rrt-007c4ae418b4c128f-b-ea-3013143-8196485-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "request validation failed",
"payload": {
"details": [
{
"message": "String \"2024-09-31\" is invalid against requested date format(s) yyyy-MM-dd: []"
}
]
}
}
} | Cambie el formato de fecha para usar YYYY-MM-DD. |
Devuelto si el formato de idioma no es válido. {
"status": "400",
"id": "rrt-007c4ae418b4c128f-b-ea-3013144-8202243-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "request validation failed",
"payload": {
"details": [
{
"message": "ECMA 262 regex \"^[a-z]{2}-[A-Z]{2}$\" does not match input string \"eg-CAI\": []"
}
]
}
}
} | El formato válido de idioma es el siguiente Formato: xx-XX xx: código de idioma en minúsculas XX: código de país en mayúsculas Debe introducirse un formato de idioma válido para producir una respuesta adecuada. |
Falta el parámetro de región. {
"status": "400",
"id": "rrt-04975a7274072003d-d-ea-3824655-7029451-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "request validation failed",
"payload": {
"details": [
{
"message": "Query parameter 'region' is required on path '/units' but not found in request.: []"
}
]
}
}
} | El parámetro región es obligatorio. |
401 No autorizado
El código de estado de error 401 Unauthorized se devuelve cuando intentas llamar a la API con un access_token expirado.
Debes obtener un nuevo access_token con una llamada a la API de Autenticación de Aplicaciones.
El código de estado de error 401 Unauthorized también se devuelve si no solicitaste acceso a la API creando un ticket en el DCP Jira.
Cuando estés listo para comenzar a trabajar en una API, debes crear un ticket de certificación en Jira, como se describe en la sección Actividades de Certificación con Jira.
Si ya comenzaste a trabajar en una API y perdiste el acceso, crea un ticket de soporte como se describe en la sección Abrir un Ticket de Soporte.
404 No Encontrado
El código de estado 404 Not Found se devuelve cuando no se encuentra el número de modelo (código de producto).
{
"status": "404",
"id": "rrt-0aa500db076dc9eed-d-ea-1328974-8146403-1.1",
"title": "not_found",
"meta": {
"service": "004",
"detail": "The product code provided was not found."
}
}El distribuidor puede haber cometido un error al introducir el número de pieza. Debe informar del error al usuario para que pueda intentarlo de nuevo.
Requisitos de DSP
Requisitos Funcionales
ID | Tipo | Requisito |
|---|---|---|
1 | Obligatorio | La API de Unidades debe ser llamada automáticamente mensualmente para obtener los cambios del catálogo de los últimos 30 días. ❗ No se debe requerir ninguna acción manual por parte del concesionario para actualizar el catálogo en su DMS ❗ |
2 | Obligatorio | El catálogo completo de unidades debe estar disponible para el concesionario. La API de Unidades debe llamarse al menos una vez para recuperar el catálogo completo. |
3 | Obligatorio | El concesionario debe poder buscar un número de producto específico en su DMS, y el resultado debe mostrarse en pantalla. |
4 | Obligatorio | El concesionario debe poder mostrar la imagen de la unidad, color, características, especificaciones técnicas, puntos destacados y todos los documentos disponibles. |
5 | Opcional | El concesionario puede obtener el catálogo de unidades para un año de modelo específico. |
6 | Opcional | El concesionario puede obtener el catálogo de unidades para una línea de productos específica. |
7 | Opcional | El concesionario puede buscar y navegar por el catálogo de unidades, filtrar el catálogo por línea de productos y buscar texto en la descripción. |
Actividades de Certificación
Esta sección presenta todas las actividades de certificación y validaciones que deben completarse para certificar la API.
Validaciones
Las pruebas enumeradas en la tabla a continuación deben realizarse correctamente en el entorno de pruebas antes de que pueda comenzar la fase piloto del distribuidor.
👉 Para la fase de prueba, su DMS debe llamar a la API de Unidades diariamente.
Una vez que finalice el piloto del concesionario, la configuración de su DMS puede modificarse para llamar a la API de Unidades mensualmente si lo prefiere.
ID | Prueba | Resultado esperado |
|---|---|---|
1 | Se carga el catálogo completo de unidades y el DMS muestra las unidades. | El catálogo completo de unidades se carga en el DMS. |
2 | La información de la unidad es visible | El DMS muestra la imagen de la unidad, color, características, especificaciones técnicas, aspectos destacados y todos los documentos disponibles. |
3 | Buscar un número de producto específico:
| Se puede buscar un número de producto específico desde el DMS y el resultado se muestra. |
4 | Recuperar las unidades para la línea de productos PWC y año modelo 2025 | Cargar o actualizar el catálogo de unidades para una línea de productos específica (PWC) y año modelo (2025). |
Piloto del Distribuidor
La siguiente tabla describe los parámetros y validaciones del piloto del concesionario.
👉 Para la fase piloto del concesionario, su DMS debe llamar a la API de Unidades diariamente.
Una vez que finalice el piloto del concesionario, la configuración de su DMS puede modificarse para llamar a la API de Unidades mensualmente si lo prefiere.
Parámetro | Valor |
|---|---|
Entorno | Producción |
Número de distribuidores | 1 a 3 |
Duración | 1 semana |
Validación 1 | El catálogo de unidades se actualiza diariamente. |
Validación 2 | El catálogo de unidades es accesible para el distribuidor. |
Validación 3 | Se puede buscar un número de producto específico desde el DMS y el resultado se muestra. |
Postman
Esta sección describe lo que está disponible en Postman para explorar la API.
Entornos
Hay un entorno de Postman disponible para probar la API de Unidades. Este entorno de Postman contiene variables utilizadas por las consultas y está configurado para conectarse al entorno de prueba.
Colecciones
La colección DMS - Units contiene ejemplos de llamadas a la API para obtener el catálogo de unidades o una unidad específica.